Resources
=========

.. contents::

Resources
---------

- `Installation guide <https://cell-acdc.readthedocs.io/en/latest/installation.html>`__.
- `User Manual <https://github.com/SchmollerLab/Cell_ACDC/blob/main/UserManual/Cell-ACDC_User_Manual.pdf>`__ with **detailed instructions**.
- `Workshop <https://youtu.be/u1cQ2MH5uEQ?si=-_hpBoJIccMRjraz>`_ at I2K Conference 2024
- `Publication <https://bmcbiol.biomedcentral.com/articles/10.1186/s12915-022-01372-6>`__ of Cell-ACDC.
- `Image.sc Forum <https://forum.image.sc/tag/cell-acdc>`_ to ask **any question**. Make sure to tag the Topic with the tag ``cell-acdc``. 
- **Report issues, request a feature or ask questions** by opening a new issue `here <https://github.com/SchmollerLab/Cell_ACDC/issues>`__.
- X `thread <https://twitter.com/frank_pado/status/1443957038841794561?s=20>`__.

Usage
-----

For details about how to use Cell-ACDC please read the User Manual
downloadable from
`here <https://github.com/SchmollerLab/Cell_ACDC/tree/main/UserManual>`__